Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(353)

Unified Diff: src/utils/SkPatchGrid.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/utils/SkParsePath.cpp ('k') | src/utils/SkPatchGrid.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/utils/SkPatchGrid.h
diff --git a/src/utils/SkPatchGrid.h b/src/utils/SkPatchGrid.h
index cf90098c6829b841fa3b9d665983ae12bc3b882d..5bc2e65df0112eff43f615a64173e85e11774cb6 100644
--- a/src/utils/SkPatchGrid.h
+++ b/src/utils/SkPatchGrid.h
@@ -88,7 +88,7 @@ public:
};
SkPatchGrid(int rows = 0, int cols = 0, VertexType flags = kNone_VertexType,
- SkXfermode* xfer = NULL);
+ SkXfermode* xfer = nullptr);
~SkPatchGrid();
@@ -103,9 +103,9 @@ public:
const SkPoint texCoords[4]);
/**
* Get patch at location (x,y). If cubics, colors or texCoords is not NULL it sets patch's
* array with its corresponding values.
* The function returns false if the cubics parameter is NULL or if the (x,y) coordinates are
* not within the range of the grid.
*/
bool getPatch(int x, int y, SkPoint cubics[12], SkColor colors[4], SkPoint texCoords[4]) const;
@@ -103,9 +103,9 @@ public:
const SkPoint texCoords[4]);
/**
- * Get patch at location (x,y). If cubics, colors or texCoords is not NULL it sets patch's
+ * Get patch at location (x,y). If cubics, colors or texCoords is not nullptr it sets patch's
* array with its corresponding values.
@@ -103,9 +103,9 @@ public:
* array with its corresponding values.
- * The function returns false if the cubics parameter is NULL or if the (x,y) coordinates are
+ * The function returns false if the cubics parameter is nullptr or if the (x,y) coordinates are
* not within the range of the grid.
*/
« no previous file with comments | « src/utils/SkParsePath.cpp ('k') | src/utils/SkPatchGrid.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698